@@ -25,15 +25,15 @@
 #define LIB_MANAGER_CREATEALLMIXTURES_H
 
 #include <Composer/MixtureComposer.h>
+#include <Mixture/Functional/FuncCSMixture.h>
 #include <Mixture/Simple/SimpleMixture.h>
-#include <Mixture/Simple/Categorical/Categorical.h>
 #include <Mixture/Simple/Gaussian/Gaussian.h>
 #include <Mixture/Simple/NegativeBinomial/NegativeBinomial.h>
 #include <Mixture/Simple/Poisson/Poisson.h>
 #include <Mixture/Simple/Weibull/Weibull.h>
-#include <Mixture/Functional/FunctionalMixture.h>
-#include <Mixture/Functional/FunctionalSharedAlphaMixture.h>
-#include <Mixture/Rank/RankMixture.h>
+#include <Mixture/Functional/FuncSharedAlphaCSMixture.h>
+#include <Mixture/Rank/RankISRMixture.h>
+#include <Mixture/Simple/Multinomial/Multinomial.h>
 
 namespace mixt {
 
@@ -63,7 +63,7 @@ std::string createAllMixtures(const Graph& algo, const Graph& desc, const Graph&
 			IMixture* p_mixture = NULL;
 
 			if (idModel == "Multinomial") {
-				p_mixture = new SimpleMixture<Graph, Categorical>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
+				p_mixture = new SimpleMixture<Graph, Multinomial>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
 			}
 			
 			else if (idModel == "Gaussian") {
@@ -83,15 +83,15 @@ std::string createAllMixtures(const Graph& algo, const Graph& desc, const Graph&
 			}
 
 			if (idModel == "Func_CS") {
-				p_mixture = new FunctionalMixture<Graph>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
+				p_mixture = new FuncCSMixture<Graph>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
 			}
 
 			if (idModel == "Func_SharedAlpha_CS") {
-				p_mixture = new FunctionalSharedAlphaMixture<Graph>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
+				p_mixture = new FuncSharedAlphaCSMixture<Graph>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
 			}
 
 			if (idModel == "Rank_ISR") {
-				p_mixture = new RankMixture<Graph>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
+				p_mixture = new RankISRMixture<Graph>(data, param, out, idName, nClass, nInd, confidenceLevel, paramStr);
 			}
 
 			if (p_mixture) {
